Learn R Programming

nntrf (version 0.1.4)

nntrf_doughnut: nntrf_doughnut: a benchmark of three doughnut datasets

Description

This function compares KNN with data untransformed vs. data transformed with nntrf. In order to see what it does, check the code: nntrf::nntrf_doughnut

Usage

nntrf_doughnut(verbose = TRUE)

Arguments

verbose

(default TRUE) Print results to the console.

Value

list of:

  • Accuracies of KNN on the Doughnut Dataset: with no nntrf, with nntrf and no sigmoid, and with nntrf and no sigmoid and 5 repetitions

  • Accuracies of KNN on the DoughnutRand Dataset: with no nntrf, with nntrf and no sigmoid, and with nntrf and no sigmoid and 5 repetitions

  • Accuracies of KNN on the DoughnutRandRotated Dataset: with no nntrf, with nntrf and no sigmoid, and with nntrf and no sigmoid and 5 repetitions