Learn R Programming

nntrf (version 0.1.4)

nntrf_iris: nntrf_iris: a benchmark for the iris dataset

Description

This function compares KNN with data untransformed vs. data transformed with nntrf. In order to see what it does, check the code: nntrf::nntrf_iris

Usage

nntrf_iris(verbose = TRUE)

Arguments

verbose

(default TRUE) Print results to the console.

Value

Accuracies of KNN on the Iris Dataset: with no nntrf, and with nntrf and no sigmoid